// /**
// * Copyright (c) 2012-2025 SAP SE or an SAP affiliate company. All rights reserved.
// * Theming Engine 15.0.1
// * data:{"sModified":"2025-03-20T15:24:53Z"}
// */


/******************* FILE /Base/baseLib/sap_horizon/base.less (Version 11.28.2) *******************/


// [Tags "SapInternal", "Base", "Dimension", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "dimension"]
@sapContent_GridSize: 1rem;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary1: #ebf8ff;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary2: #0070f2;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary3: #fff;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary4: #f5f6f7;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary5: #758ca4;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary6: #131e29;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary7: #556b82;

// [Label "Shell Background Pattern Color"]
// [Description "The background pattern color of the shell. To turn off the pattern set the value to 'transparent'."]
// [Tags "ThemeSpecific", "Base", "Shell", "Color", "!Protected"]
// [Protected "!true"]
// [Category "Resource"]
// [Type "color"]
@sapShell_BackgroundPatternColor: transparent;
@sapField_HorizonNGEnabled: 0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBrandColor: @sapPrimary2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapHighlightColor: darken(@sapBrandColor, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapBaseColor: @sapPrimary3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShellColor: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBackgroundColor: @sapPrimary4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontFamily: "72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontSize: 0.875 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTextColor: @sapPrimary6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLinkColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapCompanyLogo: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFavicon: @sapShell_Favicon;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBackgroundImage: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBackgroundImageOpacity: 1.0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBackgroundImageRepeat: false;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSelectedColor: @sapHighlightColor;
@sapHoverColor: darken(@sapBackgroundColor, 4);

// [Tags "!Protected"]
// [Protected "!true"]
@sapActiveColor: darken(@sapPrimary4, 8);

// [Tags "!Protected"]
// [Protected "!true"]
@sapHighlightTextColor: contrast(@sapHighlightColor, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTitleColor: @sapTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNegativeColor: #aa0808;

// [Tags "!Protected"]
// [Protected "!true"]
@sapCriticalColor: #e76500;

// [Tags "!Protected"]
// [Protected "!true"]
@sapPositiveColor: #256f3a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformativeColor: #0070f2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNeutralColor: #788fa6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNegativeElementColor: lighten(@sapNegativeColor, 23);

// [Tags "!Protected"]
// [Protected "!true"]
@sapCriticalElementColor: @sapCriticalColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapPositiveElementColor: lighten(@sapPositiveColor, 9);

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformativeElementColor: @sapInformativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNeutralElementColor: @sapNeutralColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNegativeTextColor: @sapNegativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapCriticalTextColor: darken(@sapCriticalColor, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapPositiveTextColor: @sapPositiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformativeTextColor: darken(@sapInformativeColor, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapNeutralTextColor: @sapTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapErrorColor: @sapNegativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapWarningColor: @sapCriticalColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSuccessColor: @sapPositiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformationColor: @sapInformativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapErrorBackground: #ffeaf4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapWarningBackground: #fff8d6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSuccessBackground: #f5fae5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformationBackground: #e1f4ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNeutralBackground: #eff1f2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapErrorBorderColor: lighten(@sapErrorColor, 13);

// [Tags "!Protected"]
// [Protected "!true"]
@sapWarningBorderColor: darken(@sapWarningColor, 2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapSuccessBorderColor: lighten(@sapSuccessColor, 9);

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformationBorderColor: @sapInformationColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNeutralBorderColor: @sapNeutralColor;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_LineHeight: 2.75 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_Height: 2.25 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_BorderWidth: 0.0625 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapElement_BorderCornerRadius: 0.75 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_Compact_LineHeight: 2 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_Compact_Height: 1.625 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_Condensed_LineHeight: 1.5 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_Condensed_Height: 1.375 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_LineHeight: 1.5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_IconHeight: @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_IconColor: @sapTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastIconColor: @sapContent_ContrastTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_NonInteractiveIconColor: @sapPrimary5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_MarkerIconColor: @sapAccentColor5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_MarkerTextColor: @sapAccentColor7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_MeasureIndicatorColor: @sapField_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_MeasureIndicatorColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Placeholderloading_Background: darken(@sapBaseColor, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Placeholderloading_Gradient: linear-gradient(to right, @sapContent_Placeholderloading_Background 0%, @sapContent_Placeholderloading_Background 20%, darken(@sapContent_Placeholderloading_Background, 20) 50%, @sapContent_Placeholderloading_Background 80%, @sapContent_Placeholderloading_Background 100%);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ImagePlaceholderBackground: @sapAccentBackgroundColor10;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ImagePlaceholderForegroundColor: @sapAccentColor10;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_RatedColor: @sapAccentColor1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_UnratedColor: @sapPrimary5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_BusyColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_FocusColor: #0032a5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_FocusStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_FocusWidth: 0.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastFocusColor: #fff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ShadowColor: #223548;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastShadowColor: #fff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Shadow0: 0 0 0.125rem 0 fade(@sapContent_ShadowColor, 20), 0 0.125rem 0.25rem 0 fade(@sapContent_ShadowColor, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Shadow1: 0 0 0 0.0625rem fade(@sapContent_ShadowColor, 48), 0 0.125rem 0.5rem 0 fade(@sapContent_ShadowColor, 30);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Shadow2: 0 0 0 0.0625rem fade(@sapContent_ShadowColor, 48), 0 0.625rem 1.875rem 0 fade(@sapContent_ShadowColor, 25);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Shadow3: 0 0 0 0.0625rem fade(@sapContent_ShadowColor, 48), 0 1.25rem 5rem 0 fade(@sapContent_ShadowColor, 25);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_TextShadow: 0 0 0.125rem @sapContent_ContrastShadowColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastTextShadow: 0 0 0.0625rem fade(darken(@sapContent_ShadowColor, 21), 70);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_HeaderShadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 5), inset 0 -0.0625rem 0 0 @sapObjectHeader_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Interaction_Shadow: inset 0 0 0 0.0625rem fade(@sapField_BorderColor, 25);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_Shadow: inset 0 0 0 0.0625rem fade(lighten(@sapSelectedColor, 23), 50);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Negative_Shadow: inset 0 0 0 0.0625rem fade(darken(@sapField_InvalidBackground, 18), 45);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Critical_Shadow: inset 0 0 0 0.0625rem fade(darken(@sapField_WarningBackground, 40), 40);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Positive_Shadow: inset 0 0 0 0.0625rem fade(@sapField_SuccessColor, 18);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Informative_Shadow: inset 0 0 0 0.0625rem fade(lighten(@sapField_InformationColor, 23), 50);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Neutral_Shadow: inset 0 0 0 0.0625rem fade(@sapNeutralColor, 30);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_SearchHighlightColor: #dafdf5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_HelpColor: #188918;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_LabelColor: @sapPrimary7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_MonospaceFontFamily: "72Mono", "72Monofull", lucida console, monospace;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_MonospaceBoldFontFamily: "72Mono-Bold", "72Mono-Boldfull", lucida console, monospace;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_IconFontFamily: "SAP-icons";

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_DisabledTextColor: fade(@sapTextColor, (100 - (@sapContent_DisabledOpacity * 100)));

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_DisabledOpacity: 0.4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastTextThreshold: 0.65;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastTextColor: @sapPrimary3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ForegroundColor: darken(@sapBaseColor, 6.1);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ForegroundBorderColor: @sapPrimary5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ForegroundTextColor: contrast(@sapContent_ForegroundColor, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_BadgeBackground: @sapAccentColor2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_BadgeTextColor: contrast(@sapContent_BadgeBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_BadgeBorderColor: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_DragAndDropActiveColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_TextColor: contrast(@sapContent_Selected_Background, @sapSelectedColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_Background: @sapPrimary3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_Hover_Background: lighten(@sapSelectedColor, 52);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_ForegroundColor: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ForcedColorAdjust: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Lite_Shadow: None;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color1: #9b015d;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color2: #56bdff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color3: #ff7f4c;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color4: #00144a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color5: #a9b4be;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color6: #d5dadd;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color7: lighten(@sapContent_Illustrative_Color20, 16);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color8: #fff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color9: #0899a7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color10: lighten(@sapContent_Illustrative_Color20, 16);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color11: #df1278;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color12: #00a800;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color13: #0070f2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color14: #0040b0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color15: #c35500;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color16: #8d2a00;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color17: #046c7c;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color18: lighten(@sapContent_Illustrative_Color20, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color19: lighten(@sapContent_Illustrative_Color20, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color20: #89d1ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color21: #1b90ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color22: #00144a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color23: #d20a0a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color24: #ffb2d2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color25: #ffeaf4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color26: #ffdf72;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color27: #fff8d6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color28: #a93e00;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color29: #450b00;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color30: #340800;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color31: #ffab92;
@sapContent_Space_S: 1rem;
@sapContent_Space_M: 2rem;
@sapContent_Space_L: 2rem;
@sapContent_Space_XL: 3rem;
@sapContent_Space_Tiny: 2rem;
@sapContent_Space_Small: 1rem;
@sapContent_Space_Medium: 2rem;
@sapContent_Space_Large: 3rem;
@sapContent_Margin_Tiny: 0 0 1rem;
@sapContent_Margin_Small: 1rem;
@sapContent_Margin_Medium: 1rem 2rem;
@sapContent_Margin_Large: 1rem;
@sapContent_Padding_S: 0rem;
@sapContent_Padding_M: 2rem;
@sapContent_Padding_L: 2rem;
@sapContent_Padding_XL: 3rem;
@sapContent_Gap: 1rem;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Success_HeaderShadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 5), inset 0 -0.0625rem 0 0 @sapSuccessBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Warning_HeaderShadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 5), inset 0 -0.0625rem 0 0 @sapWarningBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Error_HeaderShadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 5), inset 0 -0.0625rem 0 0 @sapErrorBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Information_HeaderShadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 5), inset 0 -0.0625rem 0 0 @sapInformationBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontLightFamily: "72-Light", "72-Lightfull", "72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontBoldFamily: "72-Bold", "72-Boldfull", "72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontSemiboldFamily: "72-Semibold", "72-Semiboldfull", "72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontSemiboldDuplexFamily: "72-SemiboldDuplex", "72-SemiboldDuplexfull", "72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontBlackFamily: "72Black", "72Blackfull","72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeaderFamily: @sapFontBoldFamily;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontSmallSize: 0.75 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontLargeSize: 1.0 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader1Size: 3.0 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader2Size: 2.0 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader3Size: 1.5 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader4Size: 1.25 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader5Size: 1.0 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader6Size: 0.875 * @sapContent_GridSize;
@sapLink_TextDecoration: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLink_Hover_Color: @sapLinkColor;
@sapLink_Hover_TextDecoration: underline;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLink_Active_Color: @sapLinkColor;
@sapLink_Active_TextDecoration: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLink_Visited_Color: @sapLinkColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLink_InvertedColor: lighten(@sapLinkColor, 40);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLink_SubtleColor: @sapTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Background: darken(@sapBackgroundColor, 2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_BackgroundImage: linear-gradient(to bottom, @sapShell_Background, @sapShell_Background);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_BackgroundImageOpacity: 1.0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_BackgroundImageRepeat: false;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_BorderColor: @sapShellColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_TextColor: contrast(@sapShellColor, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_InteractiveBackground: @sapShell_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_InteractiveTextColor: @sapShell_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_InteractiveBorderColor: @sapField_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_GroupTitleTextColor: @sapTitleColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_GroupTitleTextShadow: 0 0 0.125rem contrast(@sapShell_GroupTitleTextColor, @sapContent_ShadowColor, @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Hover_Background: @sapShellColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Active_Background: @sapShellColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Active_TextColor: contrast(@sapShell_Active_Background, @sapPrimary2, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Selected_Background: @sapShellColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Selected_TextColor: contrast(@sapShell_Selected_Background, @sapPrimary2, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Selected_Hover_Background: @sapShellColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Favicon: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_Background: @sapShellColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_Hover_Background: @sapShell_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_SelectedColor: @sapShell_Navigation_Selected_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_Selected_TextColor: contrast(@sapShell_Navigation_Background, @sapHighlightColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_TextColor: contrast(@sapShell_Navigation_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_Active_TextColor: contrast(@sapShell_Navigation_Active_Background, @sapHighlightColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_Active_Background: @sapShell_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Shadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 15), inset 0 -0.0625rem 0 0 fade(@sapContent_ShadowColor, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_NegativeColor: @sapNegativeTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_CriticalColor: @sapCriticalTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_PositiveColor: @sapPositiveTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_InformativeColor: @sapInformativeTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_NeutralColor: @sapNeutralTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Assistant_ForegroundColor: @sapAssistant_Color1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_SubBrand_TextColor: contrast(@sapShellColor, darken(@sapBrandColor, 21), @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_1_Background: #0057d2;
@sapShell_Category_1_BorderColor: @sapShell_Category_1_Background;
@sapShell_Category_1_TextColor: contrast(@sapShell_Category_1_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_1_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_1_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_2_Background: #df1278;
@sapShell_Category_2_BorderColor: @sapShell_Category_2_Background;
@sapShell_Category_2_TextColor: contrast(@sapShell_Category_2_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_2_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_2_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_3_Background: #e76500;
@sapShell_Category_3_BorderColor: @sapShell_Category_3_Background;
@sapShell_Category_3_TextColor: contrast(@sapShell_Category_3_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_3_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_3_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_4_Background: #7800a4;
@sapShell_Category_4_BorderColor: @sapShell_Category_4_Background;
@sapShell_Category_4_TextColor: contrast(@sapShell_Category_4_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_4_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_4_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_5_Background: #aa2608;
@sapShell_Category_5_BorderColor: @sapShell_Category_5_Background;
@sapShell_Category_5_TextColor: contrast(@sapShell_Category_5_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_5_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_5_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_6_Background: #07838f;
@sapShell_Category_6_BorderColor: @sapShell_Category_6_Background;
@sapShell_Category_6_TextColor: contrast(@sapShell_Category_6_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_6_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_6_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_7_Background: #f31ded;
@sapShell_Category_7_BorderColor: @sapShell_Category_7_Background;
@sapShell_Category_7_TextColor: contrast(@sapShell_Category_7_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_7_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_7_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_8_Background: #188918;
@sapShell_Category_8_BorderColor: @sapShell_Category_8_Background;
@sapShell_Category_8_TextColor: contrast(@sapShell_Category_8_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_8_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_8_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_9_Background: #002a86;
@sapShell_Category_9_BorderColor: @sapShell_Category_9_Background;
@sapShell_Category_9_TextColor: contrast(@sapShell_Category_9_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_9_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_9_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_10_Background: #5b738b;
@sapShell_Category_10_BorderColor: @sapShell_Category_10_Background;
@sapShell_Category_10_TextColor: contrast(@sapShell_Category_10_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_10_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_10_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_11_Background: #d20a0a;
@sapShell_Category_11_BorderColor: @sapShell_Category_11_Background;
@sapShell_Category_11_TextColor: contrast(@sapShell_Category_11_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_11_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_11_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_12_Background: #7858ff;
@sapShell_Category_12_BorderColor: @sapShell_Category_12_Background;
@sapShell_Category_12_TextColor: contrast(@sapShell_Category_12_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_12_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_12_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_13_Background: #a00875;
@sapShell_Category_13_BorderColor: @sapShell_Category_13_Background;
@sapShell_Category_13_TextColor: contrast(@sapShell_Category_13_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_13_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_13_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_14_Background: #14565b;
@sapShell_Category_14_BorderColor: @sapShell_Category_14_Background;
@sapShell_Category_14_TextColor: contrast(@sapShell_Category_14_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_14_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_14_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_15_Background: #223548;
@sapShell_Category_15_BorderColor: @sapShell_Category_15_Background;
@sapShell_Category_15_TextColor: contrast(@sapShell_Category_15_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_15_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_15_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_16_Background: #1e592f;
@sapShell_Category_16_BorderColor: @sapShell_Category_16_Background;
@sapShell_Category_16_TextColor: contrast(@sapShell_Category_16_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_16_TextShadow: 0 0 0.0625rem contrast(@sapShell_Category_16_TextColor, fade(darken(@sapContent_ShadowColor, 100), 70), @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapShell_Space_S: 0.5rem;
@sapShell_Space_M: 2rem;
@sapShell_Space_L: 2rem;
@sapShell_Space_XL: 3rem;
@sapShell_Gap_S: 0.5rem;
@sapShell_Gap_M: 1rem;
@sapShell_Gap_L: 1rem;
@sapShell_Gap_XL: 1rem;
@sapShell_GroupGap_S: 2rem;
@sapShell_GroupGap_M: 3rem;
@sapShell_GroupGap_L: 3rem;
@sapShell_GroupGap_XL: 3rem;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Color1: #5d36ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Color2: #a100c2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_BackgroundGradient: linear-gradient(@sapAssistant_Color1, @sapAssistant_Color2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Background: @sapAssistant_Color1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_BorderColor: @sapAssistant_Color1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_TextColor: contrast(@sapAssistant_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Hover_Background: darken(@sapAssistant_Color1, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Hover_BorderColor: @sapAssistant_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Hover_TextColor: contrast(@sapAssistant_Hover_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Active_BorderColor: contrast(@sapAssistant_Active_Background, @sapAssistant_Color1, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Active_TextColor: contrast(@sapAssistant_Active_Background, @sapAssistant_Color1, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Question_Background: lighten(@sapAssistant_Background, 34.3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Question_BorderColor: @sapAssistant_Question_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Question_TextColor: contrast(@sapAssistant_Question_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Answer_Background: @sapNeutralBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Answer_BorderColor: @sapAssistant_Answer_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Answer_TextColor: contrast(@sapAssistant_Answer_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_1_Background: @sapAccentBackgroundColor1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_1_BorderColor: @sapAvatar_1_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_1_TextColor: contrast(@sapAvatar_1_Background, darken(@sapAccentColor1, 9), @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_1_Hover_Background: @sapAvatar_1_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_2_Background: @sapAccentBackgroundColor2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_2_BorderColor: @sapAvatar_2_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_2_TextColor: contrast(@sapAvatar_2_Background, @sapAccentColor2, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_2_Hover_Background: @sapAvatar_2_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_3_Background: @sapAccentBackgroundColor3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_3_BorderColor: @sapAvatar_3_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_3_TextColor: contrast(@sapAvatar_3_Background, @sapAccentColor3, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_3_Hover_Background: @sapAvatar_3_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_4_Background: @sapAccentBackgroundColor4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_4_BorderColor: @sapAvatar_4_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_4_TextColor: contrast(@sapAvatar_4_Background, @sapAccentColor4, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_4_Hover_Background: @sapAvatar_4_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_5_Background: @sapAccentBackgroundColor5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_5_BorderColor: @sapAvatar_5_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_5_TextColor: contrast(@sapAvatar_5_Background, darken(@sapAccentColor5, 2), @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_5_Hover_Background: @sapAvatar_5_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_6_Background: @sapAccentBackgroundColor6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_6_BorderColor: @sapAvatar_6_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_6_TextColor: contrast(@sapAvatar_6_Background, @sapAccentColor6, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_6_Hover_Background: @sapAvatar_6_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_7_Background: @sapAccentBackgroundColor7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_7_BorderColor: @sapAvatar_7_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_7_TextColor: contrast(@sapAvatar_7_Background, @sapAccentColor7, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_7_Hover_Background: @sapAvatar_7_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_8_Background: @sapAccentBackgroundColor8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_8_BorderColor: @sapAvatar_8_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_8_TextColor: contrast(@sapAvatar_8_Background, @sapAccentColor8, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_8_Hover_Background: @sapAvatar_8_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_9_Background: @sapAccentBackgroundColor9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_9_BorderColor: @sapAvatar_9_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_9_TextColor: contrast(@sapAvatar_9_Background, @sapAccentColor9, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_9_Hover_Background: @sapAvatar_9_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_10_Background: @sapAccentBackgroundColor10;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_10_BorderColor: @sapAvatar_10_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_10_TextColor: contrast(@sapAvatar_10_Background, darken(@sapAccentColor10, 3), @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_10_Hover_Background: @sapAvatar_10_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_Lite_BorderColor: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_Lite_Background: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_Hover_BorderColor: fade(@sapField_BorderColor, 25);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Background: lighten(@sapBackgroundColor, 4);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_BorderColor: darken(@sapBackgroundColor, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_BorderCornerRadius: 0.5 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_TextColor: contrast(@sapButton_Background, @sapHighlightColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_FontFamily: @sapFontSemiboldDuplexFamily;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Hover_Background: @sapHoverColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Hover_BorderColor: @sapButton_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Hover_TextColor: contrast(@sapButton_Hover_Background, @sapHighlightColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_IconColor: @sapButton_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Active_Background: lighten(@sapActiveColor, 11.5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Active_BorderColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Active_TextColor: contrast(@sapButton_Active_Background, @sapHighlightColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Background: @sapBrandColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_BorderColor: @sapButton_Emphasized_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_TextColor: contrast(@sapButton_Emphasized_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_FontFamily: @sapFontBoldFamily;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Hover_Background: darken(@sapButton_Emphasized_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Hover_BorderColor: darken(@sapButton_Emphasized_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Hover_TextColor: contrast(@sapButton_Emphasized_Hover_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Active_BorderColor: @sapButton_Active_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Active_TextColor: contrast(@sapButton_Emphasized_Active_Background, @sapHighlightColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_TextShadow: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_FontWeight: bold;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Background: darken(@sapErrorBackground, 4);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_BorderColor: darken(@sapButton_Reject_Background, 4);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_TextColor: contrast(@sapButton_Reject_Background, @sapNegativeTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Hover_Background: darken(@sapButton_Reject_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Hover_BorderColor: darken(@sapButton_Reject_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Hover_TextColor: contrast(@sapButton_Reject_Hover_Background, @sapNegativeTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Active_BorderColor: @sapErrorBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Active_TextColor: contrast(@sapButton_Reject_Active_Background, @sapNegativeTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Selected_Background: @sapButton_Reject_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Selected_BorderColor: @sapButton_Reject_Active_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Selected_TextColor: contrast(@sapButton_Reject_Selected_Background, @sapNegativeTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Selected_Hover_Background: @sapButton_Reject_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Selected_Hover_BorderColor: @sapButton_Reject_Selected_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Background: darken(@sapSuccessBackground, 6);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_BorderColor: darken(@sapButton_Accept_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_TextColor: contrast(@sapButton_Accept_Background, @sapPositiveTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Hover_Background: darken(@sapButton_Accept_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Hover_BorderColor: darken(@sapButton_Accept_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Hover_TextColor: contrast(@sapButton_Accept_Hover_Background, @sapPositiveTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Active_BorderColor: @sapSuccessBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Active_TextColor: contrast(@sapButton_Accept_Active_Background, @sapPositiveTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Selected_Background: @sapButton_Accept_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Selected_BorderColor: @sapButton_Accept_Active_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Selected_TextColor: contrast(@sapButton_Accept_Selected_Background, @sapPositiveTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Selected_Hover_Background: @sapButton_Accept_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Selected_Hover_BorderColor: @sapButton_Accept_Selected_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Background: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_BorderColor: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_TextColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Hover_Background: @sapButton_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Hover_BorderColor: @sapButton_Hover_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Hover_TextColor: @sapButton_Lite_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Active_BorderColor: @sapButton_Active_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_Background: lighten(@sapSelectedColor, 54);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_BorderColor: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_TextColor: contrast(@sapButton_Selected_Background, @sapSelectedColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_Hover_Background: darken(@sapButton_Selected_Background, 4);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_Hover_BorderColor: @sapButton_Selected_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Background: darken(@sapWarningBackground, 6);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_BorderColor: darken(@sapButton_Attention_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_TextColor: contrast(@sapButton_Attention_Background, @sapCriticalTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Hover_Background: darken(@sapButton_Attention_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Hover_BorderColor: darken(@sapButton_Attention_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Hover_TextColor: contrast(@sapButton_Attention_Hover_Background, @sapCriticalTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Active_BorderColor: @sapWarningBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Active_TextColor: contrast(@sapButton_Attention_Active_Background, @sapCriticalTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Selected_Background: @sapButton_Attention_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Selected_BorderColor: @sapButton_Attention_Active_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Selected_TextColor: contrast(@sapButton_Attention_Selected_Background, @sapCriticalTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Selected_Hover_Background: @sapButton_Attention_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Selected_Hover_BorderColor: @sapButton_Attention_Active_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Background: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_BorderColor: @sapButton_Negative_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_TextColor: contrast(@sapButton_Negative_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Hover_Background: darken(@sapButton_Negative_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Hover_BorderColor: @sapButton_Negative_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Hover_TextColor: contrast(@sapButton_Negative_Hover_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Active_BorderColor: @sapButton_Negative_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Active_TextColor: contrast(@sapButton_Negative_Active_Background, @sapNegativeTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Background: @sapCriticalElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_BorderColor: @sapButton_Critical_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_TextColor: contrast(@sapButton_Critical_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Hover_Background: darken(@sapButton_Critical_Background, 2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Hover_BorderColor: @sapButton_Critical_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Hover_TextColor: contrast(@sapButton_Critical_Hover_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Active_BorderColor: darken(@sapButton_Critical_BorderColor, 2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Active_TextColor: contrast(@sapButton_Critical_Active_Background, @sapCriticalTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Background: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_BorderColor: @sapButton_Success_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_TextColor: contrast(@sapButton_Success_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Hover_Background: darken(@sapButton_Success_Background, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Hover_BorderColor: @sapButton_Success_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Hover_TextColor: contrast(@sapButton_Success_Hover_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Active_BorderColor: @sapButton_Success_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Active_TextColor: contrast(@sapButton_Success_Active_Background, @sapPositiveTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Background: lighten(@sapInformationColor, 48);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_BorderColor: darken(@sapButton_Information_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_TextColor: contrast(@sapButton_Information_Background, @sapInformativeTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Hover_Background: darken(@sapButton_Information_Background, 4);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Hover_BorderColor: @sapButton_Information_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Hover_TextColor: contrast(@sapButton_Information_Hover_Background, @sapInformativeTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Active_BorderColor: @sapButton_Active_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Active_TextColor: contrast(@sapButton_Information_Active_Background, @sapButton_Active_TextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Background: @sapButton_Information_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_BorderColor: @sapButton_Information_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_TextColor: @sapButton_Information_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Hover_Background: @sapButton_Information_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Hover_BorderColor: @sapButton_Information_Hover_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Hover_TextColor: @sapButton_Information_Hover_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Active_Background: @sapButton_Information_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Active_BorderColor: @sapButton_Information_Active_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Active_TextColor: @sapButton_Information_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Background: @sapNeutralElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_BorderColor: @sapButton_Track_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_TextColor: contrast(@sapButton_Track_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Hover_Background: darken(@sapButton_Track_Background, 7);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Hover_BorderColor: @sapButton_Track_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Selected_Background: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Selected_BorderColor: @sapButton_Track_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Selected_TextColor: contrast(@sapButton_Track_Selected_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Selected_Hover_Background: darken(@sapButton_Track_Selected_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Selected_Hover_BorderColor: @sapButton_Track_Selected_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Background: @sapPrimary3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_BorderColor: @sapButton_Handle_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_TextColor: contrast(@sapButton_Handle_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Hover_Background: @sapButton_Handle_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Hover_BorderColor: fade(@sapButton_Handle_Background, 50);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Selected_Background: @sapButton_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Selected_BorderColor: @sapButton_Handle_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Selected_TextColor: @sapButton_Selected_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Selected_Hover_Background: @sapButton_Handle_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Selected_Hover_BorderColor: fade(@sapButton_Handle_Selected_Background, 50);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Negative_Background: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Negative_BorderColor: @sapButton_Track_Negative_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Negative_TextColor: contrast(@sapButton_Track_Negative_Background, @sapNegativeElementColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Negative_Hover_Background: darken(@sapButton_Track_Negative_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Negative_Hover_BorderColor: @sapButton_Track_Negative_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Negative_Background: @sapButton_Handle_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Negative_BorderColor: @sapButton_Handle_Negative_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Negative_TextColor: contrast(@sapButton_Handle_Negative_Background, @sapNegativeTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Negative_Hover_Background: @sapButton_Handle_Negative_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Negative_Hover_BorderColor: fade(@sapButton_Handle_Negative_Background, 50);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Positive_Background: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Positive_BorderColor: @sapButton_Track_Positive_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Positive_TextColor: contrast(@sapButton_Track_Positive_Background, @sapPositiveElementColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Positive_Hover_Background: darken(@sapButton_Track_Positive_Background, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Positive_Hover_BorderColor: @sapButton_Track_Positive_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Positive_Background: @sapPrimary3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Positive_BorderColor: @sapButton_Handle_Positive_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Positive_TextColor: contrast(@sapButton_Handle_Positive_Background, @sapPositiveTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Positive_Hover_Background: @sapButton_Handle_Positive_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Positive_Hover_BorderColor: fade(@sapButton_Handle_Positive_Background, 50);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_TokenBackground: @sapButton_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_TokenBorderColor: @sapButton_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_TokenBorderCornerRadius: 0.375 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_TokenBorderWidth: 0.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_ReadOnly_TokenBackground: @sapButton_TokenBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Segment_BorderCornerRadius: @sapButton_BorderCornerRadius;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Background: mix(@sapBaseColor, darken(@sapPrimary4, 2), @sapField_HorizonNGEnabled * 100);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_BackgroundStyle: ~"0 100% / 100% @{sapField_BorderWidth} no-repeat linear-gradient(0deg, @{sapField_BorderColor}, @{sapField_BorderColor}) border-box";

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_TextColor: @sapTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_PlaceholderTextColor: @sapContent_LabelColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_BorderColor: darken(@sapPrimary5, 13);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_HelpBackground: @sapField_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_BorderStyle: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_BorderCornerRadius: 0.25 * @sapContent_GridSize;
@sapField_Shadow: inset 0 0 0 0.0625rem fade(@sapField_BorderColor, 25);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Hover_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Hover_BackgroundStyle: ~"0 100% / 100% @{sapField_BorderWidth} no-repeat linear-gradient(0deg, @{sapField_Hover_BorderColor}, @{sapField_Hover_BorderColor}) border-box";

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Hover_BorderColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Hover_HelpBackground: @sapField_Hover_Background;
@sapField_Hover_Shadow: inset 0 0 0 0.0625rem fade(lighten(@sapField_Hover_BorderColor, 23), 50);
@sapField_Hover_InvalidShadow: @sapField_InvalidShadow;
@sapField_Hover_WarningShadow: @sapField_WarningShadow;
@sapField_Hover_SuccessShadow: @sapField_SuccessShadow;
@sapField_Hover_InformationShadow: @sapField_InformationShadow;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Active_BorderColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Focus_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Focus_BorderColor: @sapContent_FocusColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Focus_HelpBackground: @sapField_Focus_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_ReadOnly_Background: mix(darken(@sapPrimary4, 4), transparent, @sapField_HorizonNGEnabled * 100);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_ReadOnly_BackgroundStyle: ~"0 100% / 0.375rem @{sapField_BorderWidth} repeat-x linear-gradient(90deg, @{sapField_ReadOnly_BorderColor} 0, @{sapField_ReadOnly_BorderColor} 0.25rem, transparent 0.25rem) border-box";

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_ReadOnly_BorderColor: @sapField_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_ReadOnly_BorderStyle: @sapField_BorderStyle;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_ReadOnly_HelpBackground: @sapField_ReadOnly_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_RequiredColor: @sapAccentColor3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InvalidColor: @sapErrorBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InvalidBackground: @sapErrorBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InvalidBackgroundStyle: ~"0 100% / 100% @{sapField_InvalidBorderWidth} no-repeat linear-gradient(0deg, @{sapField_InvalidColor}, @{sapField_InvalidColor}) border-box";

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InvalidBorderWidth: 0.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InvalidBorderStyle: none;
@sapField_InvalidShadow: inset 0 0 0 0.0625rem fade(darken(@sapField_InvalidBackground, 18), 45);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_WarningColor: @sapWarningBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_WarningBackground: @sapWarningBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_WarningBackgroundStyle: ~"0 100% / 100% @{sapField_WarningBorderWidth} no-repeat linear-gradient(0deg, @{sapField_WarningColor}, @{sapField_WarningColor}) border-box";

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_WarningBorderWidth: 0.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_WarningBorderStyle: none;
@sapField_WarningShadow: inset 0 0 0 0.0625rem fade(darken(@sapField_WarningBackground, 40), 40);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_SuccessColor: @sapSuccessBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_SuccessBackground: @sapSuccessBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_SuccessBackgroundStyle: ~"0 100% / 100% @{sapField_SuccessBorderWidth} no-repeat linear-gradient(0deg, @{sapField_SuccessColor}, @{sapField_SuccessColor}) border-box";

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_SuccessBorderWidth: 0.0625 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_SuccessBorderStyle: none;
@sapField_SuccessShadow: inset 0 0 0 0.0625rem fade(@sapField_SuccessColor, 18);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InformationColor: @sapInformationBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InformationBackground: @sapInformationBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InformationBackgroundStyle: ~"0 100% / 100% @{sapField_InformationBorderWidth} no-repeat linear-gradient(0deg, @{sapField_InformationColor}, @{sapField_InformationColor}) border-box";

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InformationBorderWidth: 0.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InformationBorderStyle: none;
@sapField_InformationShadow: inset 0 0 0 0.0625rem fade(lighten(@sapField_InformationColor, 23), 50);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_Hover_Background: @sapContent_Selected_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_Hover_InvalidBackground: @sapField_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_Hover_WarningBackground: @sapField_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_Hover_SuccessBackground: @sapField_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_Hover_InformationBackground: @sapField_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Picker_BorderColor: @sapField_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Picker_BorderWidth: 0.0625 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_BorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_ReadOnly_BorderStyle: dashed;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_InvalidBorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_WarningBorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_SuccessBorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_InformationBorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_TitleBorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_TitleBackground: @sapGroup_ContentBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_TitleBorderColor: lighten(desaturate(@sapPrimary5, 7), 15);

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_TitleTextColor: contrast(@sapGroup_TitleBackground, @sapTitleColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_Title_FontSize: @sapFontHeader5Size;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_ContentBackground: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_ContentBorderColor: darken(@sapGroup_ContentBackground, 15);

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_BorderCornerRadius: 0.75 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_FooterBackground: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapToolbar_Background: @sapGroup_ContentBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapToolbar_SeparatorColor: darken(@sapBaseColor, 15);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_HeaderBackground: @sapList_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_HeaderBorderColor: @sapGroup_TitleBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_HeaderTextColor: contrast(@sapList_HeaderBackground, @sapTitleColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_BorderColor: darken(@sapList_Background, 10.2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TextColor: contrast(@sapList_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_Active_TextColor: contrast(@sapList_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_Active_Background: @sapActiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_SelectionBackgroundColor: @sapPrimary1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_SelectionBorderColor: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_Hover_SelectionBackground: contrast(@sapList_SelectionBackgroundColor, darken(@sapList_SelectionBackgroundColor, 3), lighten(@sapList_SelectionBackgroundColor, 3));

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_Hover_Background: @sapHoverColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_AlternatingBackground: @sapPrimary4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_GroupHeaderBackground: @sapList_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_GroupHeaderBorderColor: @sapList_HeaderBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_GroupHeaderTextColor: contrast(@sapList_GroupHeaderBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableGroupHeaderBackground: darken(@sapPrimary4, 2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableGroupHeaderBorderColor: @sapList_GroupHeaderBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableGroupHeaderTextColor: contrast(@sapList_TableGroupHeaderBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_FooterBackground: @sapList_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_FooterTextColor: contrast(@sapList_FooterBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableFooterBorder: @sapList_HeaderBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableFixedBorderColor: darken(@sapList_BorderColor, 35);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableFixedColumnBorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableFixedRowBorderWidth: 0.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_ErrorBorderColor: darken(@sapErrorBackground, 18);

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_WarningBorderColor: darken(@sapWarningBackground, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_SuccessBorderColor: darken(@sapSuccessBackground, 24);

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_InformationBorderColor: darken(@sapInformationBackground, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_Button_Hover_Background: fade(@sapButton_Lite_Hover_Background, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapPopover_BorderCornerRadius: 0.5 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Background: darken(@sapNeutralBackground, 9.2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_BorderColor: @sapProgress_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_TextColor: @sapTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_FontSize: @sapFontSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_NegativeBackground: darken(@sapErrorBackground, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_NegativeBorderColor: @sapProgress_NegativeBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_NegativeTextColor: @sapProgress_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_CriticalBackground: darken(@sapWarningBackground, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_CriticalBorderColor: @sapProgress_CriticalBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_CriticalTextColor: @sapProgress_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_PositiveBackground: darken(@sapSuccessBackground, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_PositiveBorderColor: @sapProgress_PositiveBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_PositiveTextColor: @sapProgress_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_InformationBackground: darken(@sapInformationBackground, 4);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_InformationBorderColor: @sapProgress_InformationBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_InformationTextColor: @sapProgress_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_Background: darken(@sapNeutralElementColor, 8);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_BorderColor: @sapProgress_Value_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_TextColor: @sapNeutralElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_NegativeBackground: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_NegativeBorderColor: @sapProgress_Value_NegativeBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_NegativeTextColor: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_CriticalBackground: @sapCriticalElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_CriticalBorderColor: @sapProgress_Value_CriticalBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_CriticalTextColor: @sapCriticalElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_PositiveBackground: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_PositiveBorderColor: @sapProgress_Value_PositiveBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_PositiveTextColor: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_InformationBackground: @sapInformativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_InformationBorderColor: @sapProgress_Value_InformationBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_InformationTextColor: @sapInformativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_FaceColor: lighten(@sapPrimary5, 2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_TrackColor: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_BorderColor: @sapScrollBar_FaceColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_SymbolColor: @sapButton_Lite_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_Dimension: 0.75 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_Hover_FaceColor: darken(@sapScrollBar_FaceColor, 12);

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Background: darken(@sapNeutralBackground, 9.2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_BorderColor: @sapSlider_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Selected_Background: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Selected_BorderColor: @sapSlider_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_HandleBackground: @sapPrimary3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_HandleBorderColor: lighten(@sapHighlightColor, 42);

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_RangeHandleBackground: @sapSlider_HandleBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Hover_HandleBackground: @sapButton_Selected_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Hover_HandleBorderColor: @sapSlider_HandleBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Hover_RangeHandleBackground: @sapSlider_Hover_HandleBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Active_HandleBackground: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Active_HandleBorderColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Active_RangeHandleBackground: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageHeader_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageHeader_BorderColor: darken(@sapPageHeader_Background, 15);

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageHeader_TextColor: contrast(@sapPageHeader_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageFooter_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageFooter_BorderColor: darken(@sapPageFooter_Background, 15);

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageFooter_TextColor: contrast(@sapPageFooter_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapInfobar_Background: @sapAccentBackgroundColor7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInfobar_Hover_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInfobar_Active_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInfobar_NonInteractive_Background: @sapPrimary4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInfobar_TextColor: contrast(@sapInfobar_Background, @sapAccentColor7, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Hover_Background: @sapHoverColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_BorderColor: darken(@sapObjectHeader_Background, 15);

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Title_TextColor: contrast(@sapObjectHeader_Background, @sapTitleColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Title_FontSize: @sapFontHeader3Size;

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Title_SnappedFontSize: @sapFontHeader4Size;

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Title_FontFamily: @sapFontBlackFamily;

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Subtitle_TextColor: contrast(@sapObjectHeader_Background, @sapContent_LabelColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapBlockLayer_Background: #000;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBlockLayer_Opacity: 0.2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_TextColor: @sapTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_ForegroundColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_IconColor: contrast(@sapTab_Background, @sapHighlightColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Background: @sapObjectHeader_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Selected_TextColor: @sapContent_Selected_ForegroundColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Selected_IconColor: contrast(@sapTab_Selected_Background, @sapContent_Selected_ForegroundColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Selected_Background: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Selected_Indicator_Dimension: 0.1875 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_TextColor: @sapPositiveTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_ForegroundColor: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_IconColor: contrast(@sapTab_Background, @sapPositiveElementColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_Selected_TextColor: @sapPositiveTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_Selected_IconColor: contrast(@sapTab_Positive_Selected_Background, @sapTextColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_Selected_Background: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_TextColor: @sapNegativeTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_ForegroundColor: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_IconColor: contrast(@sapTab_Background, @sapNegativeElementColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_Selected_TextColor: @sapNegativeTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_Selected_IconColor: contrast(@sapTab_Negative_Selected_Background, @sapTextColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_Selected_Background: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_TextColor: @sapCriticalTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_ForegroundColor: @sapCriticalElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_IconColor: contrast(@sapTab_Background, @sapCriticalElementColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_Selected_TextColor: @sapCriticalTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_Selected_IconColor: contrast(@sapTab_Critical_Selected_Background, @sapTextColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_Selected_Background: @sapCriticalElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_TextColor: @sapNeutralTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_ForegroundColor: @sapNeutralElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_IconColor: contrast(@sapTab_Background, @sapNeutralElementColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_Selected_TextColor: @sapNeutralTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_Selected_IconColor: contrast(@sapTab_Neutral_Selected_Background, @sapTextColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_Selected_Background: @sapNeutralElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Hover_Background: @sapHoverColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Active_Background: @sapActiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_BorderColor: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_BorderCornerRadius: 1 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_TitleTextColor: contrast(@sapTile_Background, @sapTitleColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_TextColor: contrast(@sapTile_Background, @sapContent_LabelColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_IconColor: contrast(@sapTile_Background, @sapPrimary7, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_SeparatorColor: darken(@sapTile_Background, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Interactive_BorderColor: darken(@sapTile_Background, 30);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_OverlayBackground: @sapTile_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_OverlayForegroundColor: contrast(@sapTile_OverlayBackground, @sapTitleColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Hover_ContentBackground: @sapTile_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Active_ContentBackground: @sapTile_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor1: #d27700;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor2: #aa0808;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor3: #ba066c;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor4: #a100c2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor5: #5d36ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor6: #0057d2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor7: #046c7a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor8: #256f3a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor9: #6c32a9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor10: #5b738b;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor1: #fff3b8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor2: #ffd0e7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor3: #ffdbe7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor4: #ffdcf3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor5: #ded3ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor6: #d1efff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor7: #c2fcee;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor8: #ebf5cb;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor9: #ddccf0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor10: #eaecee;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1: #840606;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1_Background: @sapIndicationColor_1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1_BorderColor: @sapIndicationColor_1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1_TextColor: contrast(@sapIndicationColor_1_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1_Hover_Background: darken(@sapIndicationColor_1, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1_Active_Background: @sapButton_Active_Background;
@sapIndicationColor_1_Active_BorderColor: @sapIndicationColor_1b_BorderColor;
@sapIndicationColor_1_Active_TextColor: @sapIndicationColor_1;
@sapIndicationColor_1_Selected_Background: @sapIndicationColor_1_Active_Background;
@sapIndicationColor_1_Selected_BorderColor: @sapIndicationColor_1_Active_BorderColor;
@sapIndicationColor_1_Selected_TextColor: @sapIndicationColor_1_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1b: #fb9d9d;
@sapIndicationColor_1b_TextColor: darken(desaturate(@sapIndicationColor_1b, 1), 53);
@sapIndicationColor_1b_Background: @sapIndicationColor_1b;
@sapIndicationColor_1b_BorderColor: @sapIndicationColor_1b;
@sapIndicationColor_1b_Hover_Background: darken(@sapIndicationColor_1b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2: #aa0808;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2_Background: @sapIndicationColor_2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2_BorderColor: @sapIndicationColor_2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2_TextColor: contrast(@sapIndicationColor_2_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2_Hover_Background: darken(@sapIndicationColor_2, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2_Active_Background: @sapButton_Active_Background;
@sapIndicationColor_2_Active_BorderColor: @sapIndicationColor_2b_BorderColor;
@sapIndicationColor_2_Active_TextColor: @sapIndicationColor_2;
@sapIndicationColor_2_Selected_Background: @sapIndicationColor_2_Active_Background;
@sapIndicationColor_2_Selected_BorderColor: @sapIndicationColor_2_Active_BorderColor;
@sapIndicationColor_2_Selected_TextColor: @sapIndicationColor_2_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2b: #fcc4c4;
@sapIndicationColor_2b_TextColor: darken(saturate(@sapIndicationColor_2b, 1), 53);
@sapIndicationColor_2b_Background: @sapIndicationColor_2b;
@sapIndicationColor_2b_BorderColor: @sapIndicationColor_2b;
@sapIndicationColor_2b_Hover_Background: darken(@sapIndicationColor_2b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3: #b95100;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3_Background: #e76500;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3_BorderColor: @sapIndicationColor_3_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3_TextColor: contrast(@sapIndicationColor_3_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3_Hover_Background: darken(@sapIndicationColor_3_Background, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3_Active_Background: @sapButton_Active_Background;
@sapIndicationColor_3_Active_BorderColor: @sapIndicationColor_3b_BorderColor;
@sapIndicationColor_3_Active_TextColor: @sapIndicationColor_3;
@sapIndicationColor_3_Selected_Background: @sapIndicationColor_3_Active_Background;
@sapIndicationColor_3_Selected_BorderColor: @sapIndicationColor_3_Active_BorderColor;
@sapIndicationColor_3_Selected_TextColor: @sapIndicationColor_3_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3b: #ffdfc3;
@sapIndicationColor_3b_TextColor: darken(@sapIndicationColor_3b, 56);
@sapIndicationColor_3b_Background: @sapIndicationColor_3b;
@sapIndicationColor_3b_BorderColor: @sapIndicationColor_3b;
@sapIndicationColor_3b_Hover_Background: darken(@sapIndicationColor_3b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4: #256f3a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4_Background: @sapIndicationColor_4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4_BorderColor: @sapIndicationColor_4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4_TextColor: contrast(@sapIndicationColor_4_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4_Hover_Background: darken(@sapIndicationColor_4, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4_Active_Background: @sapButton_Active_Background;
@sapIndicationColor_4_Active_BorderColor: @sapIndicationColor_4b_BorderColor;
@sapIndicationColor_4_Active_TextColor: @sapIndicationColor_4;
@sapIndicationColor_4_Selected_Background: @sapIndicationColor_4_Active_Background;
@sapIndicationColor_4_Selected_BorderColor: @sapIndicationColor_4_Active_BorderColor;
@sapIndicationColor_4_Selected_TextColor: @sapIndicationColor_4_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4b: #bae8bc;
@sapIndicationColor_4b_TextColor: darken(@sapIndicationColor_4b, 53);
@sapIndicationColor_4b_Background: @sapIndicationColor_4b;
@sapIndicationColor_4b_BorderColor: @sapIndicationColor_4b;
@sapIndicationColor_4b_Hover_Background: darken(@sapIndicationColor_4b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5: #0070f2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5_Background: @sapIndicationColor_5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5_BorderColor: @sapIndicationColor_5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5_TextColor: contrast(@sapIndicationColor_5_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5_Hover_Background: darken(@sapIndicationColor_5, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5_Active_Background: @sapButton_Active_Background;
@sapIndicationColor_5_Active_BorderColor: @sapIndicationColor_5b_BorderColor;
@sapIndicationColor_5_Active_TextColor: @sapIndicationColor_5;
@sapIndicationColor_5_Selected_Background: @sapIndicationColor_5_Active_Background;
@sapIndicationColor_5_Selected_BorderColor: @sapIndicationColor_5_Active_BorderColor;
@sapIndicationColor_5_Selected_TextColor: @sapIndicationColor_5_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5b: #d9ebff;
@sapIndicationColor_5b_TextColor: darken(@sapIndicationColor_5b, 50);
@sapIndicationColor_5b_Background: @sapIndicationColor_5b;
@sapIndicationColor_5b_BorderColor: @sapIndicationColor_5b;
@sapIndicationColor_5b_Hover_Background: darken(@sapIndicationColor_5b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6: #046c7a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6_Background: @sapIndicationColor_6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6_BorderColor: @sapIndicationColor_6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6_TextColor: contrast(@sapIndicationColor_6_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6_Hover_Background: darken(@sapIndicationColor_6, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6_Active_Background: @sapButton_Active_Background;
@sapIndicationColor_6_Active_BorderColor: @sapIndicationColor_6b_BorderColor;
@sapIndicationColor_6_Active_TextColor: @sapIndicationColor_6;
@sapIndicationColor_6_Selected_Background: @sapIndicationColor_6_Active_Background;
@sapIndicationColor_6_Selected_BorderColor: @sapIndicationColor_6_Active_BorderColor;
@sapIndicationColor_6_Selected_TextColor: @sapIndicationColor_6_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6b: #cdf5ec;
@sapIndicationColor_6b_TextColor: darken(@sapIndicationColor_6b, 63);
@sapIndicationColor_6b_Background: @sapIndicationColor_6b;
@sapIndicationColor_6b_BorderColor: @sapIndicationColor_6b;
@sapIndicationColor_6b_Hover_Background: darken(@sapIndicationColor_6b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7: #5d36ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7_Background: @sapIndicationColor_7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7_BorderColor: @sapIndicationColor_7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7_TextColor: contrast(@sapIndicationColor_7_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7_Hover_Background: darken(@sapIndicationColor_7, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7_Active_Background: @sapButton_Active_Background;
@sapIndicationColor_7_Active_BorderColor: @sapIndicationColor_7b_BorderColor;
@sapIndicationColor_7_Active_TextColor: @sapIndicationColor_7;
@sapIndicationColor_7_Selected_Background: @sapIndicationColor_7_Active_Background;
@sapIndicationColor_7_Selected_BorderColor: @sapIndicationColor_7_Active_BorderColor;
@sapIndicationColor_7_Selected_TextColor: @sapIndicationColor_7_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7b: #e2dbff;
@sapIndicationColor_7b_TextColor: darken(@sapIndicationColor_7b, 32);
@sapIndicationColor_7b_Background: @sapIndicationColor_7b;
@sapIndicationColor_7b_BorderColor: @sapIndicationColor_7b;
@sapIndicationColor_7b_Hover_Background: darken(@sapIndicationColor_7b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8: #a100c2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8_Background: @sapIndicationColor_8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8_BorderColor: @sapIndicationColor_8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8_TextColor: contrast(@sapIndicationColor_8_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8_Hover_Background: darken(@sapIndicationColor_8, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8_Active_Background: @sapButton_Active_Background;
@sapIndicationColor_8_Active_BorderColor: @sapIndicationColor_8b_BorderColor;
@sapIndicationColor_8_Active_TextColor: @sapIndicationColor_8;
@sapIndicationColor_8_Selected_Background: @sapIndicationColor_8_Active_Background;
@sapIndicationColor_8_Selected_BorderColor: @sapIndicationColor_8_Active_BorderColor;
@sapIndicationColor_8_Selected_TextColor: @sapIndicationColor_8_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8b: #f8d6ff;
@sapIndicationColor_8b_TextColor: darken(@sapIndicationColor_8b, 54);
@sapIndicationColor_8b_Background: @sapIndicationColor_8b;
@sapIndicationColor_8b_BorderColor: @sapIndicationColor_8b;
@sapIndicationColor_8b_Hover_Background: darken(@sapIndicationColor_8b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9: #1d2d3e;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9_Background: @sapIndicationColor_9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9_BorderColor: @sapIndicationColor_9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9_TextColor: contrast(@sapIndicationColor_9_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9_Hover_Background: darken(@sapIndicationColor_9, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9_Active_Background: @sapButton_Active_Background;
@sapIndicationColor_9_Active_BorderColor: @sapIndicationColor_9b_BorderColor;
@sapIndicationColor_9_Active_TextColor: @sapIndicationColor_9;
@sapIndicationColor_9_Selected_Background: @sapIndicationColor_9_Active_Background;
@sapIndicationColor_9_Selected_BorderColor: @sapIndicationColor_9_Active_BorderColor;
@sapIndicationColor_9_Selected_TextColor: @sapIndicationColor_9_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9b: #fff;
@sapIndicationColor_9b_TextColor: darken(@sapIndicationColor_9b, 82);
@sapIndicationColor_9b_Background: @sapIndicationColor_9b;
@sapIndicationColor_9b_BorderColor: darken(@sapIndicationColor_9b, 15);
@sapIndicationColor_9b_Hover_Background: darken(@sapIndicationColor_9b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10: #45484a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10_Background: lighten(@sapIndicationColor_10, 25);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10_BorderColor: @sapIndicationColor_10_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10_TextColor: contrast(@sapIndicationColor_10_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10_Hover_Background: darken(@sapIndicationColor_10_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10_Active_Background: @sapButton_Active_Background;
@sapIndicationColor_10_Active_BorderColor: @sapIndicationColor_10b_BorderColor;
@sapIndicationColor_10_Active_TextColor: @sapIndicationColor_10;
@sapIndicationColor_10_Selected_Background: @sapIndicationColor_10_Active_Background;
@sapIndicationColor_10_Selected_BorderColor: @sapIndicationColor_10_Active_BorderColor;
@sapIndicationColor_10_Selected_TextColor: @sapIndicationColor_10_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10b: #eaecee;
@sapIndicationColor_10b_TextColor: darken(desaturate(@sapIndicationColor_10b, 8), 65);
@sapIndicationColor_10b_Background: @sapIndicationColor_10b;
@sapIndicationColor_10b_BorderColor: @sapIndicationColor_10b;
@sapIndicationColor_10b_Hover_Background: darken(@sapIndicationColor_10b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegend_WorkingBackground: @sapList_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegend_NonWorkingBackground: darken(@sapList_Background, 8);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegend_CurrentDateTime: @sapAccentColor4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor1: #c35500;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor2: #d23a0a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor3: #df1278;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor4: #840606;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor5: #cc00dc;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor6: #0057d2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor7: #07838f;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor8: #188918;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor9: #5b738b;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor10: #7800a4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor11: #a93e00;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor12: #aa2608;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor13: #ba066c;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor14: #8d2a00;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor15: #4e247a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor16: #002a86;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor17: #035663;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor18: #1e592f;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor19: #1a4796;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor20: #470ced;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor1: #ffef9f;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor2: #feeae1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor3: #fbf6f8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor4: #fbebeb;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor5: #ffe5fe;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor6: #d1efff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor7: #c2fcee;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor8: #f5fae5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor9: #f5f6f7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor10: #fff0fa;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor11: #fff8d6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor12: #fff6f6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor13: #f7ebef;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor14: #f1ecd5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor15: #f0e7f8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor16: #ebf8ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor17: #dafdf5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor18: #ebf5cb;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor19: #fafdff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor20: #eceeff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Background: @sapGroup_ContentBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_ContrastTextShadow: @sapContent_ContrastTextShadow;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_ContrastShadowColor: @sapContent_ContrastShadowColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_ContrastLineColor: @sapChart_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_LineColor_1: lighten(@sapContent_ForegroundBorderColor, 35);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_LineColor_2: darken(@sapChart_LineColor_1, 35);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_LineColor_3: darken(@sapChart_LineColor_1, 90);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Choropleth_Background: @sapChart_Sequence_Neutral_Plus3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_ChoroplethRegion_Background: @sapChart_Sequence_Neutral;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_ChoroplethRegion_BorderColor: @sapChart_Choropleth_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Data_TextColor: darken(@sapTextColor, 14);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Data_ContrastTextColor: @sapContent_ContrastTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Data_InteractiveColor: @sapChart_LineColor_3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Data_Active_Background: @sapActiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_1: #168eff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_2: #c87b00;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_3: #75980b;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_4: #df1278;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_5: #8b47d7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_6: #049f9a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_7: #0070f2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_8: #cc00dc;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_9: #798c77;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_10: #da6c6c;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_11: #5d36ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_12: #a68a5b;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Bad: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Critical: #e26300;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Good: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Neutral: #758ca4;
@sapChart_Sequence_1_Plus3: lighten(saturate(@sapChart_Sequence_1, 14), 25);
@sapChart_Sequence_1_Plus3_TextColor: contrast(@sapChart_Sequence_1_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_1_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Plus2: lighten(desaturate(@sapChart_Sequence_1, 1), 7);
@sapChart_Sequence_1_Plus2_TextColor: contrast(@sapChart_Sequence_1_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_1_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Plus1: lighten(saturate(@sapChart_Sequence_1, 12), 8);
@sapChart_Sequence_1_Plus1_TextColor: contrast(@sapChart_Sequence_1_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_1_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_1: @sapChart_OrderedColor_1;
@sapChart_Sequence_1_TextColor: contrast(@sapChart_Sequence_1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_BorderColor: @sapChart_Sequence_1;
@sapChart_Sequence_1_Minus1: darken(desaturate(@sapChart_Sequence_1, 6), 7);
@sapChart_Sequence_1_Minus1_TextColor: contrast(@sapChart_Sequence_1_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_1_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Minus2: darken(desaturate(@sapChart_Sequence_1, 6), 7);
@sapChart_Sequence_1_Minus2_TextColor: contrast(@sapChart_Sequence_1_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_1_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Minus3: darken(desaturate(@sapChart_Sequence_1, 8), 22);
@sapChart_Sequence_1_Minus3_TextColor: contrast(@sapChart_Sequence_1_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_1_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Minus4: darken(desaturate(@sapChart_Sequence_1, 7), 27);
@sapChart_Sequence_1_Minus4_TextColor: contrast(@sapChart_Sequence_1_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_1_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Minus5: darken(desaturate(@sapChart_Sequence_1, 7), 32);
@sapChart_Sequence_1_Minus5_TextColor: contrast(@sapChart_Sequence_1_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_1_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Plus3: lighten(desaturate(@sapChart_Sequence_2, 20), 30);
@sapChart_Sequence_2_Plus3_TextColor: contrast(@sapChart_Sequence_2_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Plus2: lighten(desaturate(@sapChart_Sequence_2, 20), 20);
@sapChart_Sequence_2_Plus2_TextColor: contrast(@sapChart_Sequence_2_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Plus1: lighten(desaturate(@sapChart_Sequence_2, 20), 10);
@sapChart_Sequence_2_Plus1_TextColor: contrast(@sapChart_Sequence_2_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_2: @sapChart_OrderedColor_2;
@sapChart_Sequence_2_TextColor: contrast(@sapChart_Sequence_2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_BorderColor: @sapChart_Sequence_2_Minus1;
@sapChart_Sequence_2_Minus1: darken(@sapChart_Sequence_2, 8);
@sapChart_Sequence_2_Minus1_TextColor: contrast(@sapChart_Sequence_2_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Minus2: darken(@sapChart_Sequence_2, 15);
@sapChart_Sequence_2_Minus2_TextColor: contrast(@sapChart_Sequence_2_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Minus3: darken(@sapChart_Sequence_2, 20);
@sapChart_Sequence_2_Minus3_TextColor: contrast(@sapChart_Sequence_2_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Minus4: darken(@sapChart_Sequence_2, 20);
@sapChart_Sequence_2_Minus4_TextColor: contrast(@sapChart_Sequence_2_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Minus5: darken(@sapChart_Sequence_2, 30);
@sapChart_Sequence_2_Minus5_TextColor: contrast(@sapChart_Sequence_2_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Plus3: lighten(desaturate(@sapChart_Sequence_3, 32), 30);
@sapChart_Sequence_3_Plus3_TextColor: contrast(@sapChart_Sequence_3_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Plus2: lighten(desaturate(@sapChart_Sequence_3, 32), 20);
@sapChart_Sequence_3_Plus2_TextColor: contrast(@sapChart_Sequence_3_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Plus1: lighten(desaturate(@sapChart_Sequence_3, 32), 12);
@sapChart_Sequence_3_Plus1_TextColor: contrast(@sapChart_Sequence_3_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_3: @sapChart_OrderedColor_3;
@sapChart_Sequence_3_TextColor: contrast(@sapChart_Sequence_3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_BorderColor: @sapChart_Sequence_3_Minus1;
@sapChart_Sequence_3_Minus1: darken(@sapChart_Sequence_3, 8);
@sapChart_Sequence_3_Minus1_TextColor: contrast(@sapChart_Sequence_3_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Minus2: darken(@sapChart_Sequence_3, 15);
@sapChart_Sequence_3_Minus2_TextColor: contrast(@sapChart_Sequence_3_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Minus3: darken(@sapChart_Sequence_3, 20);
@sapChart_Sequence_3_Minus3_TextColor: contrast(@sapChart_Sequence_3_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Minus4: darken(@sapChart_Sequence_3, 23);
@sapChart_Sequence_3_Minus4_TextColor: contrast(@sapChart_Sequence_3_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Minus5: darken(@sapChart_Sequence_3, 26);
@sapChart_Sequence_3_Minus5_TextColor: contrast(@sapChart_Sequence_3_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Plus3: lighten(@sapChart_Sequence_4, 23);
@sapChart_Sequence_4_Plus3_TextColor: contrast(@sapChart_Sequence_4_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Plus2: lighten(@sapChart_Sequence_4, 15);
@sapChart_Sequence_4_Plus2_TextColor: contrast(@sapChart_Sequence_4_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Plus1: lighten(@sapChart_Sequence_4, 7);
@sapChart_Sequence_4_Plus1_TextColor: contrast(@sapChart_Sequence_4_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_4: @sapChart_OrderedColor_4;
@sapChart_Sequence_4_TextColor: contrast(@sapChart_Sequence_4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_BorderColor: @sapChart_Sequence_4;
@sapChart_Sequence_4_Minus1: darken(@sapChart_Sequence_4, 8);
@sapChart_Sequence_4_Minus1_TextColor: contrast(@sapChart_Sequence_4_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Minus2: darken(@sapChart_Sequence_4, 16);
@sapChart_Sequence_4_Minus2_TextColor: contrast(@sapChart_Sequence_4_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Minus3: darken(@sapChart_Sequence_4, 22);
@sapChart_Sequence_4_Minus3_TextColor: contrast(@sapChart_Sequence_4_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Minus4: darken(@sapChart_Sequence_4, 30);
@sapChart_Sequence_4_Minus4_TextColor: contrast(@sapChart_Sequence_4_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Minus5: darken(@sapChart_Sequence_4, 35);
@sapChart_Sequence_4_Minus5_TextColor: contrast(@sapChart_Sequence_4_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Plus3: lighten(@sapChart_Sequence_5, 28);
@sapChart_Sequence_5_Plus3_TextColor: contrast(@sapChart_Sequence_5_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Plus2: lighten(desaturate(@sapChart_Sequence_5, 9), 17);
@sapChart_Sequence_5_Plus2_TextColor: contrast(@sapChart_Sequence_5_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Plus1: lighten(desaturate(@sapChart_Sequence_5, 9), 10);
@sapChart_Sequence_5_Plus1_TextColor: contrast(@sapChart_Sequence_5_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_5: @sapChart_OrderedColor_5;
@sapChart_Sequence_5_TextColor: contrast(@sapChart_Sequence_5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_BorderColor: @sapChart_Sequence_5;
@sapChart_Sequence_5_Minus1: darken(desaturate(@sapChart_Sequence_5, 10), 10);
@sapChart_Sequence_5_Minus1_TextColor: contrast(@sapChart_Sequence_5_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Minus2: darken(desaturate(@sapChart_Sequence_5, 10), 18);
@sapChart_Sequence_5_Minus2_TextColor: contrast(@sapChart_Sequence_5_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Minus3: darken(desaturate(@sapChart_Sequence_5, 10), 23);
@sapChart_Sequence_5_Minus3_TextColor: contrast(@sapChart_Sequence_5_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Minus4: darken(desaturate(@sapChart_Sequence_5, 10), 28);
@sapChart_Sequence_5_Minus4_TextColor: contrast(@sapChart_Sequence_5_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Minus5: darken(@sapChart_Sequence_5, 35);
@sapChart_Sequence_5_Minus5_TextColor: contrast(@sapChart_Sequence_5_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Plus3: lighten(desaturate(@sapChart_Sequence_6, 16), 34);
@sapChart_Sequence_6_Plus3_TextColor: contrast(@sapChart_Sequence_6_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Plus2: lighten(desaturate(@sapChart_Sequence_6, 21), 21);
@sapChart_Sequence_6_Plus2_TextColor: contrast(@sapChart_Sequence_6_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Plus1: lighten(@sapChart_Sequence_6, 8);
@sapChart_Sequence_6_Plus1_TextColor: contrast(@sapChart_Sequence_6_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_6: @sapChart_OrderedColor_6;
@sapChart_Sequence_6_TextColor: contrast(@sapChart_Sequence_6, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_BorderColor: @sapChart_Sequence_6_Plus1;
@sapChart_Sequence_6_Minus1: darken(saturate(@sapChart_Sequence_6, 3), 6);
@sapChart_Sequence_6_Minus1_TextColor: contrast(@sapChart_Sequence_6_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Minus2: darken(saturate(@sapChart_Sequence_6, 5), 12);
@sapChart_Sequence_6_Minus2_TextColor: contrast(@sapChart_Sequence_6_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Minus3: darken(saturate(@sapChart_Sequence_6, 5), 16);
@sapChart_Sequence_6_Minus3_TextColor: contrast(@sapChart_Sequence_6_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Minus4: darken(saturate(@sapChart_Sequence_6, 5), 20);
@sapChart_Sequence_6_Minus4_TextColor: contrast(@sapChart_Sequence_6_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Minus5: darken(saturate(@sapChart_Sequence_6, 5), 25);
@sapChart_Sequence_6_Minus5_TextColor: contrast(@sapChart_Sequence_6_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Plus3: lighten(@sapChart_Sequence_7, 23);
@sapChart_Sequence_7_Plus3_TextColor: contrast(@sapChart_Sequence_7_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Plus2: lighten(@sapChart_Sequence_7, 15);
@sapChart_Sequence_7_Plus2_TextColor: contrast(@sapChart_Sequence_7_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Plus1: lighten(@sapChart_Sequence_7, 8);
@sapChart_Sequence_7_Plus1_TextColor: contrast(@sapChart_Sequence_7_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_7: @sapChart_OrderedColor_7;
@sapChart_Sequence_7_TextColor: contrast(@sapChart_Sequence_7, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_BorderColor: @sapChart_Sequence_7;
@sapChart_Sequence_7_Minus1: darken(@sapChart_Sequence_7, 6);
@sapChart_Sequence_7_Minus1_TextColor: contrast(@sapChart_Sequence_7_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Minus2: darken(@sapChart_Sequence_7, 12);
@sapChart_Sequence_7_Minus2_TextColor: contrast(@sapChart_Sequence_7_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Minus3: darken(@sapChart_Sequence_7, 20);
@sapChart_Sequence_7_Minus3_TextColor: contrast(@sapChart_Sequence_7_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Minus4: darken(@sapChart_Sequence_7, 32);
@sapChart_Sequence_7_Minus4_TextColor: contrast(@sapChart_Sequence_7_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Minus5: darken(@sapChart_Sequence_7, 36);
@sapChart_Sequence_7_Minus5_TextColor: contrast(@sapChart_Sequence_7_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Plus3: lighten(@sapChart_Sequence_8, 26);
@sapChart_Sequence_8_Plus3_TextColor: contrast(@sapChart_Sequence_8_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Plus2: lighten(@sapChart_Sequence_8, 17);
@sapChart_Sequence_8_Plus2_TextColor: contrast(@sapChart_Sequence_8_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Plus1: lighten(@sapChart_Sequence_8, 9);
@sapChart_Sequence_8_Plus1_TextColor: contrast(@sapChart_Sequence_8_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_8: @sapChart_OrderedColor_8;
@sapChart_Sequence_8_TextColor: contrast(@sapChart_Sequence_8, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_BorderColor: @sapChart_Sequence_8;
@sapChart_Sequence_8_Minus1: darken(@sapChart_Sequence_8, 8);
@sapChart_Sequence_8_Minus1_TextColor: contrast(@sapChart_Sequence_8_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Minus2: darken(@sapChart_Sequence_8, 16);
@sapChart_Sequence_8_Minus2_TextColor: contrast(@sapChart_Sequence_8_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Minus3: darken(@sapChart_Sequence_8, 20);
@sapChart_Sequence_8_Minus3_TextColor: contrast(@sapChart_Sequence_8_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Minus4: darken(@sapChart_Sequence_8, 25);
@sapChart_Sequence_8_Minus4_TextColor: contrast(@sapChart_Sequence_8_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Minus5: darken(@sapChart_Sequence_8, 32);
@sapChart_Sequence_8_Minus5_TextColor: contrast(@sapChart_Sequence_8_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Plus3: lighten(@sapChart_Sequence_9, 25);
@sapChart_Sequence_9_Plus3_TextColor: contrast(@sapChart_Sequence_9_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_9_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Plus2: lighten(@sapChart_Sequence_9, 22);
@sapChart_Sequence_9_Plus2_TextColor: contrast(@sapChart_Sequence_9_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_9_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Plus1: lighten(@sapChart_Sequence_9, 11);
@sapChart_Sequence_9_Plus1_TextColor: contrast(@sapChart_Sequence_9_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_9_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_9: @sapChart_OrderedColor_9;
@sapChart_Sequence_9_TextColor: contrast(@sapChart_Sequence_9, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_9_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_BorderColor: @sapChart_Sequence_9;
@sapChart_Sequence_9_Minus1: darken(@sapChart_Sequence_9, 8);
@sapChart_Sequence_9_Minus1_TextColor: contrast(@sapChart_Sequence_9_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_9_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Minus2: darken(@sapChart_Sequence_9, 16);
@sapChart_Sequence_9_Minus2_TextColor: contrast(@sapChart_Sequence_9_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_9_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Minus3: darken(@sapChart_Sequence_9, 24);
@sapChart_Sequence_9_Minus3_TextColor: contrast(@sapChart_Sequence_9_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_9_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Minus4: darken(@sapChart_Sequence_9, 32);
@sapChart_Sequence_9_Minus4_TextColor: contrast(@sapChart_Sequence_9_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_9_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Minus5: darken(@sapChart_Sequence_9, 38);
@sapChart_Sequence_9_Minus5_TextColor: contrast(@sapChart_Sequence_9_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_9_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Plus3: lighten(@sapChart_Sequence_10, 22);
@sapChart_Sequence_10_Plus3_TextColor: contrast(@sapChart_Sequence_10_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .4);
@sapChart_Sequence_10_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Plus2: lighten(@sapChart_Sequence_10, 16);
@sapChart_Sequence_10_Plus2_TextColor: contrast(@sapChart_Sequence_10_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .4);
@sapChart_Sequence_10_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Plus1: lighten(@sapChart_Sequence_10, 8);
@sapChart_Sequence_10_Plus1_TextColor: contrast(@sapChart_Sequence_10_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .4);
@sapChart_Sequence_10_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_10: @sapChart_OrderedColor_10;
@sapChart_Sequence_10_TextColor: contrast(@sapChart_Sequence_10, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .4);
@sapChart_Sequence_10_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_BorderColor: @sapChart_Sequence_10_Minus1;
@sapChart_Sequence_10_Minus1: darken(desaturate(@sapChart_Sequence_10, 20), 11);
@sapChart_Sequence_10_Minus1_TextColor: contrast(@sapChart_Sequence_10_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .4);
@sapChart_Sequence_10_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Minus2: darken(desaturate(@sapChart_Sequence_10, 20), 20);
@sapChart_Sequence_10_Minus2_TextColor: contrast(@sapChart_Sequence_10_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .4);
@sapChart_Sequence_10_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Minus3: darken(desaturate(@sapChart_Sequence_10, 20), 28);
@sapChart_Sequence_10_Minus3_TextColor: contrast(@sapChart_Sequence_10_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .4);
@sapChart_Sequence_10_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Minus4: darken(desaturate(@sapChart_Sequence_10, 20), 35);
@sapChart_Sequence_10_Minus4_TextColor: contrast(@sapChart_Sequence_10_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .4);
@sapChart_Sequence_10_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Minus5: darken(desaturate(@sapChart_Sequence_10, 20), 40);
@sapChart_Sequence_10_Minus5_TextColor: contrast(@sapChart_Sequence_10_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .4);
@sapChart_Sequence_10_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Plus3: lighten(@sapChart_Sequence_11, 24);
@sapChart_Sequence_11_Plus3_TextColor: contrast(@sapChart_Sequence_11_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Plus2: lighten(@sapChart_Sequence_11, 15);
@sapChart_Sequence_11_Plus2_TextColor: contrast(@sapChart_Sequence_11_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Plus1: lighten(@sapChart_Sequence_11, 10);
@sapChart_Sequence_11_Plus1_TextColor: contrast(@sapChart_Sequence_11_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_11: @sapChart_OrderedColor_11;
@sapChart_Sequence_11_TextColor: contrast(@sapChart_Sequence_11, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_BorderColor: @sapChart_Sequence_11;
@sapChart_Sequence_11_Minus1: darken(desaturate(@sapChart_Sequence_11, 20), 8);
@sapChart_Sequence_11_Minus1_TextColor: contrast(@sapChart_Sequence_11_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Minus2: darken(desaturate(@sapChart_Sequence_11, 20), 16);
@sapChart_Sequence_11_Minus2_TextColor: contrast(@sapChart_Sequence_11_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Minus3: darken(desaturate(@sapChart_Sequence_11, 20), 24);
@sapChart_Sequence_11_Minus3_TextColor: contrast(@sapChart_Sequence_11_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Minus4: darken(desaturate(@sapChart_Sequence_11, 20), 32);
@sapChart_Sequence_11_Minus4_TextColor: contrast(@sapChart_Sequence_11_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Minus5: darken(desaturate(@sapChart_Sequence_11, 20), 24);
@sapChart_Sequence_11_Minus5_TextColor: contrast(@sapChart_Sequence_11_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Plus3: lighten(desaturate(@sapChart_Sequence_12, 1), 35);
@sapChart_Sequence_12_Plus3_TextColor: contrast(@sapChart_Sequence_12_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Plus2: lighten(desaturate(@sapChart_Sequence_12, 1), 29);
@sapChart_Sequence_12_Plus2_TextColor: contrast(@sapChart_Sequence_12_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Plus1: lighten(@sapChart_Sequence_12, 17);
@sapChart_Sequence_12_Plus1_TextColor: contrast(@sapChart_Sequence_12_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_12: @sapChart_OrderedColor_12;
@sapChart_Sequence_12_TextColor: contrast(@sapChart_Sequence_12, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_BorderColor: @sapChart_Sequence_12;
@sapChart_Sequence_12_Minus1: darken(@sapChart_Sequence_12, 8);
@sapChart_Sequence_12_Minus1_TextColor: contrast(@sapChart_Sequence_12_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Minus2: darken(@sapChart_Sequence_12, 14);
@sapChart_Sequence_12_Minus2_TextColor: contrast(@sapChart_Sequence_12_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Minus3: darken(@sapChart_Sequence_12, 22);
@sapChart_Sequence_12_Minus3_TextColor: contrast(@sapChart_Sequence_12_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Minus4: darken(@sapChart_Sequence_12, 30);
@sapChart_Sequence_12_Minus4_TextColor: contrast(@sapChart_Sequence_12_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Minus5: darken(@sapChart_Sequence_12, 36);
@sapChart_Sequence_12_Minus5_TextColor: contrast(@sapChart_Sequence_12_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Plus3: lighten(@sapChart_Sequence_Bad, 32);
@sapChart_Sequence_Bad_Plus3_TextColor: contrast(@sapChart_Sequence_Bad_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Plus2: lighten(@sapChart_Sequence_Bad, 22);
@sapChart_Sequence_Bad_Plus2_TextColor: contrast(@sapChart_Sequence_Bad_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Plus1: lighten(@sapChart_Sequence_Bad, 12);
@sapChart_Sequence_Bad_Plus1_TextColor: contrast(@sapChart_Sequence_Bad_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_Bad: @sapChart_Bad;
@sapChart_Sequence_Bad_TextColor: contrast(@sapChart_Sequence_Bad, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_BorderColor: @sapChart_Sequence_Bad;
@sapChart_Sequence_Bad_Minus1: darken(@sapChart_Sequence_Bad, 15);
@sapChart_Sequence_Bad_Minus1_TextColor: contrast(@sapChart_Sequence_Bad_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Minus2: darken(@sapChart_Sequence_Bad, 23);
@sapChart_Sequence_Bad_Minus2_TextColor: contrast(@sapChart_Sequence_Bad_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Minus3: darken(@sapChart_Sequence_Bad, 31);
@sapChart_Sequence_Bad_Minus3_TextColor: contrast(@sapChart_Sequence_Bad_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Minus4: darken(@sapChart_Sequence_Bad, 40);
@sapChart_Sequence_Bad_Minus4_TextColor: contrast(@sapChart_Sequence_Bad_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Minus5: darken(saturate(@sapChart_Sequence_Bad, 9), 48);
@sapChart_Sequence_Bad_Minus5_TextColor: contrast(@sapChart_Sequence_Bad_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Plus3: lighten(@sapChart_Sequence_Critical, 31);
@sapChart_Sequence_Critical_Plus3_TextColor: contrast(@sapChart_Sequence_Critical_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Plus2: lighten(@sapChart_Sequence_Critical, 18);
@sapChart_Sequence_Critical_Plus2_TextColor: contrast(@sapChart_Sequence_Critical_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Plus1: lighten(@sapChart_Sequence_Critical, 8);
@sapChart_Sequence_Critical_Plus1_TextColor: contrast(@sapChart_Sequence_Critical_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_Critical: @sapChart_Critical;
@sapChart_Sequence_Critical_TextColor: contrast(@sapChart_Sequence_Critical, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_BorderColor: @sapChart_Sequence_Critical;
@sapChart_Sequence_Critical_Minus1: darken(@sapChart_Sequence_Critical, 6);
@sapChart_Sequence_Critical_Minus1_TextColor: contrast(@sapChart_Sequence_Critical_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Minus2: darken(@sapChart_Sequence_Critical, 11);
@sapChart_Sequence_Critical_Minus2_TextColor: contrast(@sapChart_Sequence_Critical_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Minus3: darken(@sapChart_Sequence_Critical, 16);
@sapChart_Sequence_Critical_Minus3_TextColor: contrast(@sapChart_Sequence_Critical_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Minus4: darken(@sapChart_Sequence_Critical, 23);
@sapChart_Sequence_Critical_Minus4_TextColor: contrast(@sapChart_Sequence_Critical_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Minus5: darken(@sapChart_Sequence_Critical, 30);
@sapChart_Sequence_Critical_Minus5_TextColor: contrast(@sapChart_Sequence_Critical_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Plus3: lighten(@sapChart_Sequence_Good, 31);
@sapChart_Sequence_Good_Plus3_TextColor: contrast(@sapChart_Sequence_Good_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Plus2: lighten(@sapChart_Sequence_Good, 18);
@sapChart_Sequence_Good_Plus2_TextColor: contrast(@sapChart_Sequence_Good_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Plus1: lighten(@sapChart_Sequence_Good, 8);
@sapChart_Sequence_Good_Plus1_TextColor: contrast(@sapChart_Sequence_Good_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_Good: @sapChart_Good;
@sapChart_Sequence_Good_TextColor: contrast(@sapChart_Sequence_Good, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_BorderColor: @sapChart_Sequence_Good;
@sapChart_Sequence_Good_Minus1: darken(@sapChart_Sequence_Good, 6);
@sapChart_Sequence_Good_Minus1_TextColor: contrast(@sapChart_Sequence_Good_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Minus2: darken(@sapChart_Sequence_Good, 11);
@sapChart_Sequence_Good_Minus2_TextColor: contrast(@sapChart_Sequence_Good_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Minus3: darken(@sapChart_Sequence_Good, 16);
@sapChart_Sequence_Good_Minus3_TextColor: contrast(@sapChart_Sequence_Good_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Minus4: darken(@sapChart_Sequence_Good, 23);
@sapChart_Sequence_Good_Minus4_TextColor: contrast(@sapChart_Sequence_Good_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Minus5: darken(@sapChart_Sequence_Good, 30);
@sapChart_Sequence_Good_Minus5_TextColor: contrast(@sapChart_Sequence_Good_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Plus3: lighten(@sapChart_Sequence_Neutral, 39);
@sapChart_Sequence_Neutral_Plus3_TextColor: contrast(@sapChart_Sequence_Neutral_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Plus2: lighten(@sapChart_Sequence_Neutral, 25);
@sapChart_Sequence_Neutral_Plus2_TextColor: contrast(@sapChart_Sequence_Neutral_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Plus1: lighten(@sapChart_Sequence_Neutral, 12);
@sapChart_Sequence_Neutral_Plus1_TextColor: contrast(@sapChart_Sequence_Neutral_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_Neutral: @sapChart_Neutral;
@sapChart_Sequence_Neutral_TextColor: contrast(@sapChart_Sequence_Neutral, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_BorderColor: @sapChart_Sequence_Neutral;
@sapChart_Sequence_Neutral_Minus1: darken(@sapChart_Sequence_Neutral, 10);
@sapChart_Sequence_Neutral_Minus1_TextColor: contrast(@sapChart_Sequence_Neutral_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Minus2: darken(saturate(@sapChart_Sequence_Neutral, 3), 18);
@sapChart_Sequence_Neutral_Minus2_TextColor: contrast(@sapChart_Sequence_Neutral_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Minus3: darken(saturate(@sapChart_Sequence_Neutral, 7), 26);
@sapChart_Sequence_Neutral_Minus3_TextColor: contrast(@sapChart_Sequence_Neutral_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Minus4: darken(saturate(@sapChart_Sequence_Neutral, 15), 34);
@sapChart_Sequence_Neutral_Minus4_TextColor: contrast(@sapChart_Sequence_Neutral_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Minus5: darken(saturate(@sapChart_Sequence_Neutral, 11), 40);
@sapChart_Sequence_Neutral_Minus5_TextColor: contrast(@sapChart_Sequence_Neutral_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapFontUrl_SAP-icons_ttf: url(./../sap_horizon/fonts/SAP-icons.ttf);
@sapFontUrl_SAP-icons_woff: url(./../sap_horizon/fonts/SAP-icons.woff);
@sapFontUrl_SAP-icons_woff2: url(./../sap_horizon/fonts/SAP-icons.woff2);
@sapFontUrl_SAP-icons-TNT_ttf: url(./../sap_horizon/fonts/SAP-icons-TNT.ttf);
@sapFontUrl_SAP-icons-TNT_woff: url(./../sap_horizon/fonts/SAP-icons-TNT.woff);
@sapFontUrl_SAP-icons-TNT_woff2: url(./../sap_horizon/fonts/SAP-icons-TNT.woff2);
@sapFontUrl_SAP-icons-Business-Suite_ttf: url(./../sap_horizon/fonts/BusinessSuiteInAppSymbols.ttf);
@sapFontUrl_SAP-icons-Business-Suite_woff: url(./../sap_horizon/fonts/BusinessSuiteInAppSymbols.woff);
@sapFontUrl_SAP-icons-Business-Suite_woff2: url(./../sap_horizon/fonts/BusinessSuiteInAppSymbols.woff2);
@sapFontUrl_72_Regular_woff2: url(./../baseTheme/fonts/72-Regular.woff2);
@sapFontUrl_72_Regular_woff: url(./../baseTheme/fonts/72-Regular.woff);
@sapFontUrl_72_Regular_full_woff2: url(./../baseTheme/fonts/72-Regular-full.woff2);
@sapFontUrl_72_Regular_full_woff: url(./../baseTheme/fonts/72-Regular-full.woff);
@sapFontUrl_72_Bold_woff2: url(./../baseTheme/fonts/72-Bold.woff2);
@sapFontUrl_72_Bold_woff: url(./../baseTheme/fonts/72-Bold.woff);
@sapFontUrl_72_Bold_full_woff2: url(./../baseTheme/fonts/72-Bold-full.woff2);
@sapFontUrl_72_Bold_full_woff: url(./../baseTheme/fonts/72-Bold-full.woff);
@sapFontUrl_72_Semibold_woff2: url(./../baseTheme/fonts/72-Semibold.woff2);
@sapFontUrl_72_Semibold_woff: url(./../baseTheme/fonts/72-Semibold.woff);
@sapFontUrl_72_Semibold_full_woff2: url(./../baseTheme/fonts/72-Semibold-full.woff2);
@sapFontUrl_72_Semibold_full_woff: url(./../baseTheme/fonts/72-Semibold-full.woff);
@sapFontUrl_72_SemiboldDuplex_woff2: url(./../baseTheme/fonts/72-SemiboldDuplex.woff2);
@sapFontUrl_72_SemiboldDuplex_woff: url(./../baseTheme/fonts/72-SemiboldDuplex.woff);
@sapFontUrl_72_SemiboldDuplex_full_woff2: url(./../baseTheme/fonts/72-SemiboldDuplex-full.woff2);
@sapFontUrl_72_SemiboldDuplex_full_woff: url(./../baseTheme/fonts/72-SemiboldDuplex-full.woff);
@sapFontUrl_72_Light_woff2: url(./../baseTheme/fonts/72-Light.woff2);
@sapFontUrl_72_Light_woff: url(./../baseTheme/fonts/72-Light.woff);
@sapFontUrl_72_Light_full_woff2: url(./../baseTheme/fonts/72-Light-full.woff2);
@sapFontUrl_72_Light_full_woff: url(./../baseTheme/fonts/72-Light-full.woff);
@sapFontUrl_72_Black_woff2: url(./../baseTheme/fonts/72-Black.woff2);
@sapFontUrl_72_Black_woff: url(./../baseTheme/fonts/72-Black.woff);
@sapFontUrl_72_Black_full_woff2: url(./../baseTheme/fonts/72-Black-full.woff2);
@sapFontUrl_72_Black_full_woff: url(./../baseTheme/fonts/72-Black-full.woff);
@sapFontUrl_72_BoldItalic_woff2: url(./../baseTheme/fonts/72-BoldItalic.woff2);
@sapFontUrl_72_BoldItalic_woff: url(./../baseTheme/fonts/72-BoldItalic.woff);
@sapFontUrl_72_BoldItalic_full_woff2: url(./../baseTheme/fonts/72-BoldItalic-full.woff2);
@sapFontUrl_72_BoldItalic_full_woff: url(./../baseTheme/fonts/72-BoldItalic-full.woff);
@sapFontUrl_72_Condensed_woff2: url(./../baseTheme/fonts/72-Condensed.woff2);
@sapFontUrl_72_Condensed_woff: url(./../baseTheme/fonts/72-Condensed.woff);
@sapFontUrl_72_Condensed_full_woff2: url(./../baseTheme/fonts/72-Condensed-full.woff2);
@sapFontUrl_72_Condensed_full_woff: url(./../baseTheme/fonts/72-Condensed-full.woff);
@sapFontUrl_72_CondensedBold_woff2: url(./../baseTheme/fonts/72-CondensedBold.woff2);
@sapFontUrl_72_CondensedBold_woff: url(./../baseTheme/fonts/72-CondensedBold.woff);
@sapFontUrl_72_CondensedBold_full_woff2: url(./../baseTheme/fonts/72-CondensedBold-full.woff2);
@sapFontUrl_72_CondensedBold_full_woff: url(./../baseTheme/fonts/72-CondensedBold-full.woff);
@sapFontUrl_72_Italic_woff2: url(./../baseTheme/fonts/72-Italic.woff2);
@sapFontUrl_72_Italic_woff: url(./../baseTheme/fonts/72-Italic.woff);
@sapFontUrl_72_Italic_full_woff2: url(./../baseTheme/fonts/72-Italic-full.woff2);
@sapFontUrl_72_Italic_full_woff: url(./../baseTheme/fonts/72-Italic-full.woff);
@sapFontUrl_72Mono_Regular_woff2: url(./../baseTheme/fonts/72Mono-Regular.woff2);
@sapFontUrl_72Mono_Regular_woff: url(./../baseTheme/fonts/72Mono-Regular.woff);
@sapFontUrl_72Mono_Regular_full_woff2: url(./../baseTheme/fonts/72Mono-Regular-full.woff2);
@sapFontUrl_72Mono_Regular_full_woff: url(./../baseTheme/fonts/72Mono-Regular-full.woff);
@sapFontUrl_72Mono_Bold_woff2: url(./../baseTheme/fonts/72Mono-Bold.woff2);
@sapFontUrl_72Mono_Bold_woff: url(./../baseTheme/fonts/72Mono-Bold.woff);
@sapFontUrl_72Mono_Bold_full_woff2: url(./../baseTheme/fonts/72Mono-Bold-full.woff2);
@sapFontUrl_72Mono_Bold_full_woff: url(./../baseTheme/fonts/72Mono-Bold-full.woff);
@sapSvgLib_SAP-icons: none;
@sapSvgLib_SAPGUI-icons: url(./svg/libs/SAPGUI-icons.svg);
@sapSvgLib_SAPWeb-icons: url(./svg/libs/SAPWeb-icons.svg);
@sapSapThemeId: sap_horizon;
@sapBackgroundColorDefault: darken(@sapPrimary3, 3);
@sapList_HighlightColor: @sapHighlightColor;
@sapShell_BackgroundGradient: linear-gradient(to bottom, @sapShell_Background, @sapShell_Background);
@sapBreakpoint_S_Min: 0;
@sapBreakpoint_M_Min: 600px;
@sapBreakpoint_L_Min: 1024px;
@sapBreakpoint_XL_Min: 1440px;
